<?php
// api/src/Controller/CreateMediaObjectAction.php
namespace App\Controller\Publication;

use App\Repository\CategoriePublicationRepository;
use App\Repository\PublicationRepository;
use App\Repository\MediaObjectRepository;
use App\Repository\TagRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\String\Slugger\SluggerInterface;

#[AsController]
final class UpdatePublicationRequestAction extends AbstractController
{
    public function __invoke(Request $request, PublicationRepository $publicationRepository, 
    TagRepository $tagRepository, CategoriePublicationRepository $categoriePublicationRepository, 
    MediaObjectRepository $mediaObjectRepository, SluggerInterface $slugger): mixed
    {
        /** @var \App\Entity\User $user */
        $user = $this->getUser();

        $id = json_decode($request->get('id'), true);
        $post_data = json_decode($request->getContent(), true);

        $publication = $publicationRepository->find($id);
        
        $mediaObject = null;
        if($post_data['mediaObject'] != null && $post_data['mediaObject'] != null) {
            $mediaObject = $mediaObjectRepository->find($post_data['mediaObject']);
        }

        $categoriePublication = null;
        if($post_data['categoriePublication'] != null && $post_data['categoriePublication'] != null) {
            $categoriePublication = $categoriePublicationRepository->find($post_data['categoriePublication']);
        }

        $publication->setTitre($post_data['titre']);
        $publication->setContenu($post_data['contenu']);
        $publication->setEstPubliser($post_data['estPubliser']);
        $publication->setEstArchiver($post_data['estArchiver']);
        $publication->setEstArchiver($post_data['sendByNewLetter']);
        $publication->setAuteur($post_data['auteur']);
        $publication->setMediaObject($mediaObject);
        $publication->setCategoriePublication($categoriePublication);

        foreach($post_data['tags'] as $idTag) {
            $tag = $tagRepository->find($idTag);
            $publication->addTag($tag);
        }

        $publication->computeSlug($slugger);
        $records = $publicationRepository->findBy(['slug'=>$publication->getSlug()]);
        $nbRec = count($records);
        if ($nbRec > 0) {
            $slug = $publication->getSlug().'-'.mt_rand();
            $publication->setSlug($slug);
        }

        $publication->setEstSupprimer(false);
        $publication->setCreatedAt(new \DateTimeImmutable());
        $publication->setUpdatedAt(new \DateTimeImmutable());
        $publication->setUpdatedBy($user->getId());
        $publication->setCreatedBy($user->getId());
        $publicationRepository->save($publication, true);
        
        //return new ResponseApi(true, "Thématique créée avec succès !", $publication);
        return $publication;
    }
}
