<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Faq\CreateFaqRequestAction;
use App\Controller\Faq\DeleteFaqRequestAction;
use App\Controller\Faq\GetFaqRequestAction;
use App\Controller\Faq\ListFaqRequestAction;
use App\Controller\Faq\UpdateFaqRequestAction;
use App\Payload\FaqPaylod;
use App\Repository\FaqRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: FaqRepository::class)]
#[ApiResource(
    routePrefix: '/auth/faq',
    operations: [
        new Get(uriTemplate: '/white-api/faq/by-id/{id}',
        controller: GetFaqRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/faq/list',
        controller: ListFaqRequestAction::class),
        new Post(uriTemplate: '/auth/faq/create',
        controller: CreateFaqRequestAction::class,
        input: FaqPaylod::class),
        new Put(uriTemplate: '/auth/faq/modify/{id}',
        controller: UpdateFaqRequestAction::class,
        input: FaqPaylod::class),
        new Get(uriTemplate: '/auth/faq/delete/{id}',
        controller: DeleteFaqRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Faq extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $question = null;

    #[ORM\Column(length: 255)]
    private ?string $reponse = null;

    #[ORM\ManyToOne(targetEntity: CategorieFaq::class)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?CategorieFaq $categorieFaq = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getQuestion(): ?string
    {
        return $this->question;
    }

    public function setQuestion(string $question): static
    {
        $this->question = $question;

        return $this;
    }

    public function getReponse(): ?string
    {
        return $this->reponse;
    }

    public function setReponse(string $reponse): static
    {
        $this->reponse = $reponse;

        return $this;
    }

    public function getCategorieFaq(): ?CategorieFaq
    {
        return $this->categorieFaq;
    }

    public function setCategorieFaq(?CategorieFaq $categorieFaq): static
    {
        $this->categorieFaq = $categorieFaq;

        return $this;
    }

}
