<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\FlashInfo\CreateFlashInfoRequestAction;
use App\Controller\FlashInfo\DeleteFlashInfoRequestAction;
use App\Controller\FlashInfo\GetFlashInfoRequestAction;
use App\Controller\FlashInfo\ListFlashInfoRequestAction;
use App\Controller\FlashInfo\UpdateFlashInfoRequestAction;
use App\Payload\FlashInfoPaylod;
use App\Repository\FlashInfoRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: FlashInfoRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/flash-info/by-id/{id}',
        controller: GetFlashInfoRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/flash-info/list',
        controller: ListFlashInfoRequestAction::class),
        new Post(uriTemplate: '/auth/flash-info/create',
        controller: CreateFlashInfoRequestAction::class,
        input: FlashInfoPaylod::class),
        new Put(uriTemplate: '/auth/flash-info/modify/{id}',
        controller: UpdateFlashInfoRequestAction::class,
        input: FlashInfoPaylod::class),
        new Get(uriTemplate: '/auth/flash-info/delete/{id}',
        controller: DeleteFlashInfoRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class FlashInfo extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $titre = null;

    #[ORM\Column(nullable: true)]
    private ?\DateTimeImmutable $publishedAt = null;

    #[ORM\Column]
    private ?bool $estPubliser = null;

    #[ORM\ManyToOne(targetEntity: Publication::class)]
    #[ORM\JoinColumn(nullable: true)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?Publication $publication = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getTitre(): ?string
    {
        return $this->titre;
    }

    public function setTitre(string $titre): static
    {
        $this->titre = $titre;

        return $this;
    }

    public function getPublishedAt(): ?\DateTimeImmutable
    {
        return $this->publishedAt;
    }

    public function setPublishedAt(?\DateTimeImmutable $publishedAt): static
    {
        $this->publishedAt = $publishedAt;

        return $this;
    }

    public function isEstPubliser(): ?bool
    {
        return $this->estPubliser;
    }

    public function setEstPubliser(bool $estPubliser): static
    {
        $this->estPubliser = $estPubliser;

        return $this;
    }

    public function getPublication(): ?Publication
    {
        return $this->publication;
    }

    public function setPublication(?Publication $publication): static
    {
        $this->publication = $publication;

        return $this;
    }

}
