<?php
// api/src/Entity/MediaObject.php
namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\OpenApi\Model;
use App\Controller\CreateMediaObjectAction;
use App\Controller\MediaObject\DeleteMediaObjectRequestAction;
use App\Controller\MediaObject\GetMediaObjectRequestAction;
use App\Controller\MediaObject\ListMediaObjectRequestAction;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\HttpFoundation\File\File;
use Symfony\Component\Serializer\Annotation\Groups;
use App\Repository\MediaObjectRepository;

#[ORM\Entity(repositoryClass: MediaObjectRepository::class)]
#[ORM\Table(name: '`media_object`')]
#[ApiResource(
    routePrefix: '/auth/media',
    normalizationContext: ['groups' => ['media_object:read']],
    types: ['https://schema.org/MediaObject'],
    operations: [
        new Get(uriTemplate: '/by-id/{id}',
        controller: GetMediaObjectRequestAction::class),
        new GetCollection(uriTemplate: '/list',
        controller: ListMediaObjectRequestAction::class),
        new Get(uriTemplate: '/delete/{id}',
        controller: DeleteMediaObjectRequestAction::class),
        new Post(
            uriTemplate: '/create',
            controller: CreateMediaObjectAction::class,
            deserialize: false,
            validationContext: ['groups' => ['Default', 'media_object_create']],
            openapi: new Model\Operation(
                requestBody: new Model\RequestBody(
                    content: new \ArrayObject([
                        'multipart/form-data' => [
                            'schema' => [
                                'type' => 'object',
                                'properties' => [
                                    'file' => [
                                        'type' => 'string', 'format' => 'binary'
                                    ]
                                ]
                            ]
                        ]
                    ])
                )
            )
        )
    ],
    formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
    ],
    paginationEnabled: false,
)]
class MediaObject extends Commun 
{
    #[ORM\Id, ORM\Column, ORM\GeneratedValue]
    #[Groups(['media_object:read'])]
    private ?int $id = null;

    #[Groups(['media_object:read'])]
    public ?string $contentUrl = null;

    #[Groups(['media_object_create'])]
    public ?File $file = null;

    #[ORM\Column(length: 255, nullable: true)]
    #[Groups(['media_object:read'])]
    private ?string $fileName = null;

    #[ORM\Column(length: 255, nullable: true)]
    #[Groups(['media_object:read'])]
    private ?string $originalFileName = null;

    #[ORM\Column(length: 255, nullable: true)]
    #[Groups(['media_object:read'])]
    private ?string $fileExtension = null;

    #[ORM\Column(length: 255, nullable: true)]
    #[Groups(['media_object:read'])]
    private ?string $mimeType = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * @return string|null
     */
    public function getFileName()
    {
        return $this->fileName;
    }

    /**
     * @return string|null
     */
    public function getMimeType()
    {
        return $this->mimeType;
    }

    /**
     * @param string|null $mimeType
     */
    public function setMimeType($mimeType)
    {
        $this->mimeType = $mimeType;
    }

    /**
     * @return string|null
     */
    public function getOriginalFileName()
    {
        return $this->originalFileName;
    }

    /**
     * @param string|null $originalFileName
     */
    public function setOriginalFileName($originalFileName)
    {
        $this->originalFileName = $originalFileName;
    }

    /**
     * @param string|null $fileName
     */
    public function setFileName($fileName)
    {
        $this->fileName = $fileName;
    }

    /**
     * @return string|null
     */
    public function getFileExtension()
    {
        return $this->fileExtension;
    }

    /**
     * @param string|null $fileExtension
     */
    public function setFileExtension($fileExtension)
    {
        $this->fileExtension = $fileExtension;
    }

    /**
     * @return string|null
     */
    public function getContentUrl()
    {
        return '/media/' . $this->getFileName();
    }

    /**
     * @param string|null $contentUrl
     */
    public function setContentUrl($contentUrl)
    {
        $this->contentUrl = $contentUrl;
    }
}
