<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Slider\CreateSliderRequestAction;
use App\Controller\Slider\DeleteSliderRequestAction;
use App\Controller\Slider\GetSliderRequestAction;
use App\Controller\Slider\ListSliderRequestAction;
use App\Controller\Slider\UpdateSliderRequestAction;
use App\Payload\SliderPaylod;
use App\Repository\SliderRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: SliderRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/slider/by-id/{id}',
        controller: GetSliderRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/slider/list',
        controller: ListSliderRequestAction::class),
        new Post(uriTemplate: '/auth/slider/create',
        controller: CreateSliderRequestAction::class,
        input: SliderPaylod::class),
        new Put(uriTemplate: '/auth/slider/modify/{id}',
        controller: UpdateSliderRequestAction::class,
        input: SliderPaylod::class),
        new Get(uriTemplate: '/auth/slider/delete/{id}',
        controller: DeleteSliderRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Slider  extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $titre = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $contenu = null;

    #[ORM\Column(nullable: true)]
    private ?\DateTimeImmutable $publishedAt = null;

    #[ORM\Column]
    private ?bool $estPubliser = null;

    #[ORM\ManyToOne(targetEntity: MediaObject::class)]
    #[ORM\JoinColumn(nullable: false)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?MediaObject $mediaObject = null;

    #[ORM\ManyToOne(targetEntity: Publication::class)]
    #[ORM\JoinColumn(nullable: true)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?Publication $publication = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getTitre(): ?string
    {
        return $this->titre;
    }

    public function setTitre(string $titre): static
    {
        $this->titre = $titre;

        return $this;
    }

    public function getContenu(): ?string
    {
        return $this->contenu;
    }

    public function setContenu(?string $contenu): static
    {
        $this->contenu = $contenu;

        return $this;
    }

    public function getPublishedAt(): ?\DateTimeImmutable
    {
        return $this->publishedAt;
    }

    public function setPublishedAt(?\DateTimeImmutable $publishedAt): static
    {
        $this->publishedAt = $publishedAt;

        return $this;
    }

    public function isEstPubliser(): ?bool
    {
        return $this->estPubliser;
    }

    public function setEstPubliser(bool $estPubliser): static
    {
        $this->estPubliser = $estPubliser;

        return $this;
    }

    public function getMediaObject(): ?MediaObject
    {
        return $this->mediaObject;
    }

    public function setMediaObject(?MediaObject $mediaObject): static
    {
        $this->mediaObject = $mediaObject;

        return $this;
    }

    public function getPublication(): ?Publication
    {
        return $this->publication;
    }

    public function setPublication(?Publication $publication): static
    {
        $this->publication = $publication;

        return $this;
    }

}
